searchData={"items":[{"type":"module","title":"Turboprop","doc":"A toolkit to build beautiful, accessible components for Phoenix using Tailwind and Zag.","ref":"Turboprop.html"},{"type":"module","title":"Tools - Turboprop","doc":"Turboprop consists of multiple tools, each with their own purpose in building your component library.","ref":"Turboprop.html#module-tools"},{"type":"module","title":"Turboprop Hooks - Turboprop","doc":"Turboprop Hooks allow adding a ton of accessibility features to your components by simply adding a hook and a few data attributes to them.  \nThis includes:\n\n- Keyboard interactions\n- Focus management\n- ARIA attributes\n\nYou can either install and use them through the hex.pm dependency and some helpers we offer to add the relevant attributes to a component,\nor install them directly through npm and adding the attributes yourself.  \n\nAs an example, this renders a fully accessible dropdown menu:\n\n```heex\n \n   \n    Menu\n   \n   \n     \n       \n        Link\n       \n       Anchor \n     \n   \n \n```","ref":"Turboprop.html#module-turboprop-hooks"},{"type":"module","title":"Turboprop Merge - Turboprop","doc":"Turboprop Merge allows you to easily merge a list of Tailwind Classes to avoid style conflicts.\n\nImagine this component:\n\n```elixir\nattr :class, :string, doc: \"Class override\"\ndef button(assigns) do\n  ~H\"\"\"\n   Click me! \n  \"\"\"\nend\n```\n\nAnd imagine wanting to make the text a little bigger as a one-off. You've already added a `@class` attribute, but rendering the component\nwith `class=\"text-lg\"` will lead to an HTML output of `\"bg-black px-3 py-1.5 text-sm text-lg\"`, with two competing font size classes.\n\nNow, replace the `class` attribute with `class={merge([\"bg-black px-3 py-1.5 text-sm\", @class])}` and you will magically get\n`\"bg-black px-3 py-1.5 text-lg\"`.\n\n#### Prior art\n\nThis type of library exists in the JavaScript world already, in multiple flavors. Turboprop Merge was heavily inspired especially by\n[tailwind-merge](https://www.npmjs.com/package/tailwind-merge), so much so that we copied their tests as a starting point.","ref":"Turboprop.html#module-turboprop-merge"},{"type":"module","title":"Turboprop.Hooks","doc":"Turboprop Hooks offer an easy way to build accessible components.  \n\nYou can easily add features like keyboard interaction, focus management and ARIA attributes to your component.  \nTurboprop Hooks are built around the state machines of [Zag](https://zagjs.com) and offer the same rules as them. You will find a link to\neach state machine's documentation in the hook's module.","ref":"Turboprop.Hooks.html"},{"type":"module","title":"Installation - Turboprop.Hooks","doc":"","ref":"Turboprop.Hooks.html#module-installation"},{"type":"module","title":"With mix - Turboprop.Hooks","doc":"If you use the esbuild setup Phoenix ships with by default, the hooks will automatically be available to your assets after adding\nTurboprop to your `mix.exs`. You then only need to add the hooks to your LiveView configuration.","ref":"Turboprop.Hooks.html#module-with-mix"},{"type":"module","title":"With npm - Turboprop.Hooks","doc":"The hooks are also available packaged as an npm package, [`@leuchtturm/turboprop`](https://npmjs.com/package/@leuchtturm/turboprop). Add \nit to your assets by running `npm i --save-exact @leuchtturm/turboprop` or the equivalent for the package manager you are using.","ref":"Turboprop.Hooks.html#module-with-npm"},{"type":"module","title":"Loading the hooks - Turboprop.Hooks","doc":"```javascript\nimport { Hooks } from \"@leuchtturm/turboprop\";\n\nlet liveSocket = new LiveSocket(\"/live\", Socket, {\n  hooks: {\n    ...Hooks\n  },\n});\n```\n\nThat's it!","ref":"Turboprop.Hooks.html#module-loading-the-hooks"},{"type":"module","title":"Anatomy - Turboprop.Hooks","doc":"Each hook comes with a wrapper that adds the `phx-hook` directive and a bunch of `data` attributes that specify which role each element\nhas. Revisiting the dropdown menu example from the [Turboprop](`m:Turboprop`) documentation, the expanded elements look like this:\n\n```html\n \n   \n    Menu\n   \n   \n     \n       \n        Link\n       \n       \n        Anchor\n       \n     \n   \n \n```\nFor the `Menu` hook, the required parts are `trigger`, `positioner`, `content`, and `item`. In addition to that, it can also be configured\nwith optional parts like `separator` and `group`. Each hook's module will list both required and optional fields and how they relate to\neach other with nesting.  \nMost hooks only need the `data-part` attributes set, but some also have callbacks to the server where an event is required. Check the\ndocumentation for each hook.","ref":"Turboprop.Hooks.html#module-anatomy"},{"type":"function","title":"Turboprop.Hooks.id/0","doc":"","ref":"Turboprop.Hooks.html#id/0"},{"type":"module","title":"Turboprop.Hooks.Menu","doc":"Provides a robust, accessible dropdown and context menu system. This module serves as a wrapper around\n[Zag's Menu state machine](https://github.com/chakra-ui/zag/tree/main/packages/machines/menu), designed for displaying a list of actions \nor options to the user within a web application.","ref":"Turboprop.Hooks.Menu.html"},{"type":"module","title":"Required Components: - Turboprop.Hooks.Menu","doc":"- `menu`: The main container for the menu.\n- `menu_trigger`: Activates the dropdown or context menu.\n- `menu_positioner`: Controls the menu's position in the viewport.\n- `menu_content`: Contains the clickable menu items.\n- `menu_item`: Represents an individual action or option within the menu.","ref":"Turboprop.Hooks.Menu.html#module-required-components"},{"type":"module","title":"Optional Components: - Turboprop.Hooks.Menu","doc":"- `menu_item_group`: Groups related items within the menu.\n- `menu_item_group_label`: Provides a label for item groups, enhancing accessibility.\n- `menu_separator`: Visually separates items or groups within the menu.","ref":"Turboprop.Hooks.Menu.html#module-optional-components"},{"type":"module","title":"Example - Turboprop.Hooks.Menu","doc":"```heex\n \n   \n    Menu\n   \n   \n     \n      <.link navigate=\"/dashboard\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n        Dashboard\n      </.link>\n       \n       Account \n       \n        <.link navigate=\"/signup\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n          Sign up\n        </.link>\n        <.link navigate=\"/login\" class=\"block px-4 py-2 outline-0 data-[highlighted]:bg-gray-100\" {menu_item()}>\n          Login\n        </.link>\n       \n     \n   \n \n```","ref":"Turboprop.Hooks.Menu.html#module-example"},{"type":"function","title":"Turboprop.Hooks.Menu.menu/0","doc":"Wrapper element for menus.","ref":"Turboprop.Hooks.Menu.html#menu/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu/0","doc":"- `id` - Will be auto-generated if not set.","ref":"Turboprop.Hooks.Menu.html#menu/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_content/0","doc":"Wrapper around menu items.\n\nNeeds to be positioned as direct child of `menu_positioner/0`.","ref":"Turboprop.Hooks.Menu.html#menu_content/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item/0","doc":"Menu item.","ref":"Turboprop.Hooks.Menu.html#menu_item/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item/0","doc":"- `id` - Will be auto-generated if not set.","ref":"Turboprop.Hooks.Menu.html#menu_item/0-required-attributes"},{"type":"function","title":"Styling - Turboprop.Hooks.Menu.menu_item/0","doc":"When a menu item is highlighted, it will receive a `data-highlighted` attribute which can be used to style the item. If using Tailwind,\nthis can be achieved by adding `data-[highlighted]:bg-gray-100` to the class list.","ref":"Turboprop.Hooks.Menu.html#menu_item/0-styling"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item_group/0","doc":"Element to group multiple menu items together.","ref":"Turboprop.Hooks.Menu.html#menu_item_group/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item_group/0","doc":"- `id` - Will be auto-generated if not set.\n- `name` - If adding a label through `menu_item_group_label/0`, the group needs to have a name set.","ref":"Turboprop.Hooks.Menu.html#menu_item_group/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_item_group_label/0","doc":"Label for a menu group.","ref":"Turboprop.Hooks.Menu.html#menu_item_group_label/0"},{"type":"function","title":"Required attributes - Turboprop.Hooks.Menu.menu_item_group_label/0","doc":"- `data-for` - The `menu_item_group/0`'s `name`.","ref":"Turboprop.Hooks.Menu.html#menu_item_group_label/0-required-attributes"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_positioner/0","doc":"Element to position a menu in the viewport.\n\nNeeds to be positioned as direct child of `menu/0`.","ref":"Turboprop.Hooks.Menu.html#menu_positioner/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_separator/0","doc":"Element to separate menu items.\n\nNeeds to be positioned as direct child of either `menu_content/0` or `menu_item_group/0`.","ref":"Turboprop.Hooks.Menu.html#menu_separator/0"},{"type":"function","title":"Turboprop.Hooks.Menu.menu_trigger/0","doc":"Button to open a menu.\n\nNeeds to be positioned as direct child of `menu/0`.","ref":"Turboprop.Hooks.Menu.html#menu_trigger/0"},{"type":"module","title":"Turboprop.Merge","doc":"Provides a set of utilities for efficiently merging and managing class lists in Phoenix applications using Tailwind. Turboprop Merge\nensures that class conflicts are resolved before being applied to the element.\n\nTurboprop Merge intelligently handles class precedence, merges multiple class strings while eliminating redundancies, and utilizes an\ninternal caching mechanism to optimize performance for repeated merge operations. It supports complex scenarios like conditional class\napplication, as well as arbitrary values, properties and modifiers.","ref":"Turboprop.Merge.html"},{"type":"module","title":"Features - Turboprop.Merge","doc":"- **Class Merging**: Merges multiple Tailwind CSS classes into a single optimized class string.\n- **Conflict Resolution**: Prioritises the class name last added to the list.\n- **Caching Mechanism**: Uses an internal cache to speed up the merging process for classes that have been processed before.","ref":"Turboprop.Merge.html#module-features"},{"type":"function","title":"Turboprop.Merge.join/1","doc":"Joins a list of classes.","ref":"Turboprop.Merge.html#join/1"},{"type":"function","title":"Turboprop.Merge.merge/2","doc":"Joins and merges a list of classes.\n\nPasses the input to `join/1` before merging.","ref":"Turboprop.Merge.html#merge/2"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,48]}}